@@ -1,12 +1,12 @@
 package Perinci::Access;
 
-our $DATE = '2015-04-12'; # DATE
-our $VERSION = '0.41'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.42'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Scalar::Util qw(blessed);
 use URI::Split qw(uri_split uri_join);
@@ -114,7 +114,7 @@ Perinci::Access - Wrapper for Perinci Riap clients
 
 =head1 VERSION
 
-This document describes version 0.41 of Perinci::Access (from Perl distribution Perinci-Access), released on 2015-04-12.
+This document describes version 0.42 of Perinci::Access (from Perl distribution Perinci-Access), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -271,7 +271,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ac
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Access>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Access>.
 
 =head1 BUGS
 
